@@ -61,7 +61,6 @@ class Country(object):
                 return cc
         return None
 
-
     def country_from_twitter(self, tw):
         """
         Identify the country from a tweet.
@@ -79,6 +78,9 @@ class Country(object):
 
 
 def distance(lat1, lng1, lat2, lng2):
+    """ Taken from http://www.samuelbosch.com/2018/09/great-circle-calculations-with-numpy.html
+    also available at: https://raw.githubusercontent.com/samuelbosch/blogbits/master/geosrc/numpy_greatcircle.py
+    """
     # lat1, lng1 = a
     # lat2, lng2 = b
     sin_lat1, cos_lat1 = np.sin(lat1), np.cos(lat1)
@@ -126,6 +128,7 @@ def location(x):
         b = point(*long_lat)
     return b
 
+
 def _length(x):
     """
     Lenght between two points
@@ -284,13 +287,15 @@ class Mobility(object):
     :type day: datetime
     :param window: Window used to perform the analysis
     :type window: int
+    :param end: End of the period, use to override window.
+    :type end: datetime
 
     >>> from text_models.place import Mobility
     >>> mobility = Mobility(window=5)
     >>> output = mobility.displacement(level=mobility.state)
     """
 
-    def __init__(self, day=None, window=30):
+    def __init__(self, day=None, window=30, end=None):
         path = join(dirname(__file__), "data", "state.dict")
         self._states = load_model(path)
         path = join(dirname(__file__), "data", "bbox_country.dict")
@@ -299,12 +304,10 @@ class Mobility(object):
         self._dates = list()
         delta = datetime.timedelta(days=1)
         init = datetime.datetime(year=2015, month=12, day=16)
-        if day is None:
-            _ = time.localtime()
-            day = datetime.datetime(year=_.tm_year,
-                                    month=_.tm_mon,
-                                    day=_.tm_mday) - delta
-                                           
+        day = self.__handle_day(day)
+        if end is not None:
+            end = self.__handle_day(end)
+            window = (day - end).days + 1
         days = []
         while len(days) < window and day >= init:
             try:
@@ -323,6 +326,26 @@ class Mobility(object):
         self.num_users.reverse()
         self._dates.reverse()
 
+    def __handle_day(self, day):
+        """Inner function to handle the day
+        
+        :param day: day
+        :type day: None | instance
+        """
+
+        delta = datetime.timedelta(days=1)
+        if day is None:
+            _ = time.localtime()
+            day = datetime.datetime(year=_.tm_year,
+                                    month=_.tm_mon,
+                                    day=_.tm_mday) - delta
+            return day
+        if hasattr(day, "year") and hasattr(day, "month") and hasattr(day, "day"):
+            return datetime.datetime(year=day.year,
+                                     month=day.month,
+                                     day=day.day)
+        return day            
+
     @property
     def bounding_box(self):
         """Bounding box"""
