@@ -105,4 +105,12 @@ def test_map():
     dset.add(dict(buenos="malos"))
     res = dset.klass("en estos buenos dias")
     print(res)
-    assert "malos" in res
\ No newline at end of file
+    assert "malos" in res
+
+
+def test_bug_two_cons_klass():
+    from EvoMSA.utils import download
+    from microtc.utils import load_model
+    dset = load_model(download("country.ds"))
+    r = dset.klass("mexico y usa")
+    assert len(r.intersection(set(["US", "MX"]))) == 2
\ No newline at end of file
